@@ -9,17 +9,18 @@ function (net, layout = c("circ", "force", "stress", "conc",
     mirrorV, mirrorH, scl, hds, vedist, mar, ffamily, fstyle, 
     fsize, fsize2, fcol, fcol2, lclu, ...) 
 {
+    cnet <- attr(net, "class")
     flgmlvl <- FALSE
     flgcn2 <- FALSE
     flgpf <- FALSE
-    if (isTRUE("Multilevel" %in% attr(net, "class")) == TRUE) {
+    if (isTRUE("Multilevel" %in% cnet) == TRUE) {
         mlvl <- net
-        if (isTRUE("bpn" %in% attr(net, "class")) == TRUE) {
+        if (isTRUE("bpn" %in% cnet) == TRUE) {
             flgmlvl <- TRUE
             ifelse(missing(pch) == TRUE, pch <- c(rep(1, length(mlvl$lbs$dm)), 
                 rep(0, length(mlvl$lbs$cdm))), NA)
         }
-        else if (isTRUE("cn2" %in% attr(net, "class")) == TRUE) {
+        else if (isTRUE("cn2" %in% cnet) == TRUE) {
             flgcn2 <- TRUE
         }
         else {
@@ -27,13 +28,12 @@ function (net, layout = c("circ", "force", "stress", "conc",
         }
         net <- mlvl$mlnet
     }
-    else if (isTRUE("pathfinder" %in% attr(net, "class")) == 
-        TRUE) {
+    else if (isTRUE("pathfinder" %in% cnet) == TRUE) {
         flgpf <- TRUE
         maxw <- net$max
         net <- net$Q
     }
-    else if (isTRUE(attr(net, "class") == "Data.Set") == TRUE) {
+    else if (isTRUE(cnet == "Data.Set") == TRUE) {
         att <- net$net[, , which(net$atnet[[1]] == 1)]
         net <- net$net[, , which(net$atnet[[1]] == 0)]
     }
@@ -41,8 +41,8 @@ function (net, layout = c("circ", "force", "stress", "conc",
         NA
     }
     if (isTRUE(is.data.frame(net) == TRUE) == FALSE) {
-        if (isTRUE(is.list(net) == TRUE) == TRUE && isTRUE(attr(net, 
-            "class") == "Signed") == FALSE) {
+        if (isTRUE(is.list(net) == TRUE) == TRUE && isTRUE(cnet == 
+            "Signed") == FALSE) {
             net <- multiplex::transf(net, type = "toarray", lb2lb = TRUE, 
                 lbs = sort(unique(multiplex::dhc(unlist(net)))))
         }
@@ -65,7 +65,7 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         net <- as.matrix(net)
     }
-    if (isTRUE(attr(net, "class") == "Signed") == FALSE) {
+    if (isTRUE(cnet == "Signed") == FALSE) {
         ifelse(is.array(net) == TRUE || is.matrix(net) == TRUE, 
             NA, stop("\"net\" should be matrix or array."))
     }
@@ -118,7 +118,8 @@ function (net, layout = c("circ", "force", "stress", "conc",
         showLbs <- FALSE
     }
     else {
-        NA
+        ifelse(is.null(dimnames(net)[[1]]) == FALSE, showLbs <- TRUE, 
+            showLbs <- FALSE)
     }
     ifelse(missing(showAtts) == FALSE && isTRUE(showAtts == FALSE) == 
         TRUE, showAtts <- FALSE, showAtts <- TRUE)
@@ -277,9 +278,9 @@ function (net, layout = c("circ", "force", "stress", "conc",
         2), scl <- scl[1:2])
     ifelse(missing(vedist) == TRUE, vedist <- 0, NA)
     ifelse(isTRUE(vedist > 1L) == TRUE, vedist <- 1L, NA)
-    if (isTRUE(signed == TRUE) == TRUE || isTRUE(attr(net, "class") == 
-        "Signed") == TRUE) {
-        if (isTRUE(attr(net, "class") == "Signed") == TRUE) {
+    if (isTRUE(signed == TRUE) == TRUE || isTRUE(cnet == "Signed") == 
+        TRUE) {
+        if (isTRUE(cnet == "Signed") == TRUE) {
             if (any(net$val %in% c(-1, 0, 1)) == TRUE) {
                 net <- multiplex::zbind(multiplex::dichot(net$s, 
                   c = 1L), 1 - multiplex::dichot(net$s, c = 0))
@@ -320,8 +321,6 @@ function (net, layout = c("circ", "force", "stress", "conc",
     else {
         NA
     }
-    ifelse(is.null(dimnames(net)[[1]]) == FALSE, showLbs <- TRUE, 
-        showLbs <- FALSE)
     n <- dim(net)[1]
     ifelse(isTRUE(is.na(dim(net)[3]) == TRUE) == TRUE, z <- 1L, 
         z <- dim(net)[3])
@@ -610,43 +609,46 @@ function (net, layout = c("circ", "force", "stress", "conc",
         pch <- rep(pch[1], n)
     }
     if (missing(vcol) == TRUE) {
-        vcol <- grDevices::gray.colors(nclu)
-        ifelse(missing(col) == TRUE, NA, vcol <- col)
+        if (missing(col) == TRUE) {
+            vcol <- grDevices::gray.colors(nclu)
+        }
+        else {
+            vcol <- col
+        }
     }
-    else {
-        if (isTRUE(length(vcol) == 1L) == TRUE) {
-            vcol <- rep(vcol, n)
-        }
-        else if (isTRUE(length(vcol) != n) == TRUE & isTRUE(nclu == 
-            1) == TRUE) {
-            vcol <- rep(vcol[1], n)
-        }
-        else if (isTRUE(nclu < length(vcol)) == TRUE || identical(vcol, 
-            clu) == FALSE || missing(lclu) == FALSE) {
-            tmpvcol <- rep(0, n)
-            if (missing(lclu) == FALSE) {
-                if (isTRUE(min(lclu) == 0L) == TRUE) {
-                  lclu[which(lclu == 0L)] <- max(lclu) + 1L
-                  lclu <- sort(lclu)
-                  clu[which(clu == 0L)] <- max(lclu)
-                }
-                for (i in seq_len(nclu)) {
-                  tmpvcol[which(clu == lclu[i])] <- vcol[i]
-                }
-                rm(i)
-            }
-            else {
-                for (i in seq_len(nclu)) {
-                  tmpvcol[which(clu == (levels(factor(clu))[i]))] <- vcol[i]
-                }
-                rm(i)
-            }
-            vcol <- tmpvcol
-            rm(tmpvcol)
-        }
-        vcol[which(is.na(vcol))] <- graphics::par()$bg
-        vcol[which(vcol == 0)] <- graphics::par()$bg
+    if (isTRUE(length(vcol) == 1L) == TRUE) {
+        vcol <- rep(vcol, n)
     }
+    else if (isTRUE(length(vcol) != n) == TRUE & isTRUE(nclu == 
+        1) == TRUE) {
+        vcol <- rep(vcol[1], n)
+    }
+    else if ((isTRUE(length(vcol) == nclu) == TRUE) && (isTRUE(nclu < 
+        length(vcol)) == TRUE || identical(vcol, clu) == FALSE || 
+        missing(lclu) == FALSE)) {
+        tmpvcol <- rep(0, n)
+        if (missing(lclu) == FALSE) {
+            if (isTRUE(min(lclu) == 0L) == TRUE) {
+                lclu[which(lclu == 0L)] <- max(lclu) + 1L
+                lclu <- sort(lclu)
+                clu[which(clu == 0L)] <- max(lclu)
+            }
+            for (i in seq_len(nclu)) {
+                tmpvcol[which(clu == lclu[i])] <- vcol[i]
+            }
+            rm(i)
+        }
+        else {
+            for (i in seq_len(nclu)) {
+                tmpvcol[which(clu == (levels(factor(clu))[i]))] <- vcol[i]
+            }
+            rm(i)
+        }
+        vcol <- tmpvcol
+        rm(tmpvcol)
+    }
+    vcol[which(is.na(vcol))] <- graphics::par()$bg
+    vcol[which(vcol == 0)] <- graphics::par()$bg
     if (isTRUE(any(pch %in% 21:25)) == TRUE) {
         if (missing(vcol0) == TRUE || isTRUE(vcol0 == 0) == TRUE) {
             vcol0 <- vcol
@@ -677,7 +679,7 @@ function (net, layout = c("circ", "force", "stress", "conc",
         vcol0 <- vcol
     }
     if (isTRUE(n > 20) == TRUE) {
-        ffds <- 0.2
+        ffds <- n/100
     }
     else if (isTRUE(n == 2) == TRUE) {
         ffds <- -5
